/**
 * Copyright 2019, Danang Galuh Tegar Prasetyo.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import Client from './Client';
import Session from './Session';
import Schema from './Schema';
import TableInsert from './TableInsert';
import TableSelect from './TableSelect';
import TableUpdate from './TableUpdate';
import TableDelete from './TableDelete';
import SearchCondition from './types/SearchCondition';
import SearchConditionString from './types/SearchConditionString';
export declare class Table {
    private readonly schema;
    private readonly xTable;
    constructor(schema: Schema, xTable: any);
    private static createConditionString;
    getClient(): Client | null;
    getSession(): Session;
    getSchema(): Schema;
    getXTable(): any;
    count(): Promise<number>;
    delete(condition?: SearchCondition | SearchConditionString): TableDelete;
    existsInDatabase(): Promise<boolean>;
    getName(): string;
    insert(fields: string[]): TableInsert;
    insert(fields: {
        [k: string]: any;
    }): TableInsert;
    insert(...fields: string[]): TableInsert;
    inspect(): Object;
    isView(): Promise<boolean>;
    select(fields: string[]): TableSelect;
    select(...fields: string[]): TableSelect;
    update(condition?: SearchCondition | SearchConditionString): TableUpdate;
}
export default Table;
